Index: trunk/psLib/src/image/psImageManip.h
===================================================================
--- trunk/psLib/src/image/psImageManip.h	(revision 1635)
+++ trunk/psLib/src/image/psImageManip.h	(revision 2204)
@@ -11,6 +11,6 @@
  *  @author Ross Harman, MHPCC
  *
- *  @version $Revision: 1.13 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-08-27 19:49:54 $
+ *  @version $Revision: 1.14 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -30,7 +30,7 @@
  *  defined for psU8, psU16, psS8, psS16, psF32, psF64, psC32, and psC64.
  *
  *  @return int     The number of clipped pixels
  */
-int psImageClip(
+psS32 psImageClip(
     psImage* input,                    ///< the image to clip
     psF64 min,                         ///< the minimum image value allowed
@@ -47,7 +47,7 @@
  *  This function is defined for psC32, and psC64 imagery only.
  *
  *  @return int     The number of clipped pixels
  */
-int psImageClipComplexRegion(
+psS32 psImageClipComplexRegion(
     psImage* input,                    ///< the image to clip
     psC64 min,                         ///< the minimum image value allowed
@@ -62,7 +62,7 @@
  *  function is defined for psF32, psF64, psC32, and psC64.
  *
  *  @return int     The number of clipped pixels
  */
-int psImageClipNaN(
+psS32 psImageClipNaN(
     psImage* input,                    ///< the image to clip
     psF64 value                        ///< the value to set all NaN/Inf values to
@@ -78,11 +78,11 @@
  *  function is defined for psU8, psS8, psS16, psF32, psF64, psC32, and psC64.
  *
  *  @return int         0 if success, non-zero if failed.
  */
-int psImageOverlaySection(
+psS32 psImageOverlaySection(
     psImage* image,                    ///< target image
     const psImage* overlay,            ///< the overlay image
-    int col0,                          ///< the column to start overlay
-    int row0,                          ///< the row to start overlay
+    psS32 col0,                          ///< the column to start overlay
+    psS32 row0,                          ///< the row to start overlay
     const char *op                     ///< the operation to perform for overlay
 );
@@ -103,5 +103,5 @@
     const psImage* restrict mask,      ///< mask for input image.  If NULL, no masking is done.
     psMaskType maskVal,                ///< the bits to check in mask.
-    unsigned int scale,                ///< the scale to rebin for each dimension
+    psU32 scale,                ///< the scale to rebin for each dimension
     const psStats* stats
     ///< the statistic to perform when rebinning.  Only one method should be set.
@@ -121,5 +121,5 @@
     psImage* out,                      ///< an psImage to recycle.  If NULL, a new image is created
     const psImage* in,                 ///< input image
-    int scale,                         ///< resample scaling factor
+    psS32 scale,                         ///< resample scaling factor
     psImageInterpolateMode mode        ///< the interpolation mode used in resampling
 );
@@ -176,6 +176,6 @@
     psImage* out,                      ///< an psImage to recycle.  If NULL, a new image is created
     const psImage* in,                 ///< input image
-    int dx,                            ///< number of pixels to roll in the x-dimension
-    int dy                             ///< number of pixels to roll in the y-dimension
+    psS32 dx,                            ///< number of pixels to roll in the x-dimension
+    psS32 dy                             ///< number of pixels to roll in the y-dimension
 );
 
@@ -30,7 +30,7 @@
  *  defined for psU8, psU16, psS8, psS16, psF32, psF64, psC32, and psC64.
  *
- *  @return int     The number of clipped pixels
+ *  @return psS32     The number of clipped pixels
  */
@@ -47,7 +47,7 @@
  *  This function is defined for psC32, and psC64 imagery only.
  *
- *  @return int     The number of clipped pixels
+ *  @return psS32     The number of clipped pixels
  */
@@ -62,7 +62,7 @@
  *  function is defined for psF32, psF64, psC32, and psC64.
  *
- *  @return int     The number of clipped pixels
+ *  @return psS32     The number of clipped pixels
  */
@@ -78,11 +78,11 @@
  *  function is defined for psU8, psS8, psS16, psF32, psF64, psC32, and psC64.
  *
- *  @return int         0 if success, non-zero if failed.
+ *  @return psS32         0 if success, non-zero if failed.
  */
